@@ -166,6 +166,7 @@ CREATE TABLE IF NOT EXISTS sites (
     user_variables JSON COMMENT 'User-configured variables for the container type',
     active BOOLEAN DEFAULT TRUE,
     auto_recreate_on_update TINYINT(1) DEFAULT 0 COMMENT 'Automatically recreate containers when new image versions are available',
+    queue_id INT NULL COMMENT 'Reference to container deployment queue',
     -- SSL/HAProxy Configuration (Future Implementation)
     ssl_enabled TINYINT(1) DEFAULT 0 COMMENT 'SSL certificate enabled (0=No, 1=Let\'s Encrypt, 2=Custom)',
     ssl_certificate_path VARCHAR(255) DEFAULT NULL COMMENT 'Path to SSL certificate file',
@@ -181,6 +182,7 @@ CREATE TABLE IF NOT EXISTS sites (
     updated_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP ON UPDATE CURRENT_TIMESTAMP,
     FOREIGN KEY (primary_domain_id) REFERENCES domains(id) ON DELETE CASCADE,
     FOREIGN KEY (container_type_id) REFERENCES container_types(id) ON DELETE RESTRICT,
+    FOREIGN KEY (queue_id) REFERENCES container_deployment_queue(id) ON DELETE SET NULL,
     INDEX idx_site_name (site_name),
     INDEX idx_username (username),
     INDEX idx_primary_domain (primary_domain_id),
@@ -230,6 +232,23 @@ CREATE INDEX IF NOT EXISTS idx_sites_username_active ON sites (username, active)
 CREATE INDEX IF NOT EXISTS idx_site_containers_site_status ON site_containers (site_id, status);
 CREATE INDEX IF NOT EXISTS idx_site_domains_site_primary ON site_domains (site_id, is_primary);
 
+-- Container deployment queue for asynchronous site creation
+CREATE TABLE IF NOT EXISTS container_deployment_queue (
+    id INT AUTO_INCREMENT PRIMARY KEY,
+    site_id INT NOT NULL,
+    config JSON NOT NULL,
+    status ENUM('pending', 'processing', 'completed', 'failed') DEFAULT 'pending',
+    error_message TEXT NULL,
+    created_at TIMESTAMP DEFAULT CURRENT_TIMESTAMP,
+    processed_at TIMESTAMP NULL,
+    retry_count INT DEFAULT 0,
+    max_retries INT DEFAULT 3,
+    INDEX idx_status (status),
+    INDEX idx_site_id (site_id),
+    INDEX idx_created_at (created_at),
+    FOREIGN KEY (site_id) REFERENCES sites(id) ON DELETE CASCADE
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4 COLLATE=utf8mb4_unicode_ci;
+
 -- ================================================
 -- ANNOUNCEMENTS SYSTEM
 -- ================================================
