@@ -25,7 +25,7 @@ class ContainerQueue {
             }
             
             $stmt = $this->pdo->prepare("
-                INSERT INTO container_deployment_queue (site_id, config, status) 
+                INSERT INTO whp.container_deployment_queue (site_id, config, status) 
                 VALUES (?, ?, 'pending')
             ");
             $stmt->execute([$site_id, $json_config]);
@@ -33,7 +33,7 @@ class ContainerQueue {
             $queue_id = $this->pdo->lastInsertId();
             
             // Update sites table with queue_id
-            $update_stmt = $this->pdo->prepare("UPDATE sites SET queue_id = ? WHERE id = ?");
+            $update_stmt = $this->pdo->prepare("UPDATE whp.sites SET queue_id = ? WHERE id = ?");
             $update_stmt->execute([$queue_id, $site_id]);
             
             return $queue_id;
@@ -50,8 +50,8 @@ class ContainerQueue {
         try {
             $stmt = $this->pdo->prepare("
                 SELECT q.*, s.domain_name 
-                FROM container_deployment_queue q
-                JOIN sites s ON q.site_id = s.id
+                FROM whp.container_deployment_queue q
+                JOIN whp.sites s ON q.site_id = s.id
                 WHERE q.site_id = ? 
                 ORDER BY q.created_at DESC 
                 LIMIT 1
@@ -73,7 +73,7 @@ class ContainerQueue {
             
             // Use FOR UPDATE to lock the row atomically
             $stmt = $this->pdo->prepare("
-                SELECT * FROM container_deployment_queue 
+                SELECT * FROM whp.container_deployment_queue 
                 WHERE status = 'pending' 
                 ORDER BY created_at ASC 
                 LIMIT 1
@@ -85,7 +85,7 @@ class ContainerQueue {
             if ($deployment) {
                 // Immediately mark as processing to prevent race conditions
                 $update = $this->pdo->prepare("
-                    UPDATE container_deployment_queue 
+                    UPDATE whp.container_deployment_queue 
                     SET status = 'processing', processed_at = NOW() 
                     WHERE id = ?
                 ");
@@ -109,7 +109,7 @@ class ContainerQueue {
     public function markAsProcessing($queue_id) {
         try {
             $stmt = $this->pdo->prepare("
-                UPDATE container_deployment_queue 
+                UPDATE whp.container_deployment_queue 
                 SET status = 'processing', processed_at = NOW() 
                 WHERE id = ?
             ");
@@ -126,7 +126,7 @@ class ContainerQueue {
     public function markAsCompleted($queue_id) {
         try {
             $stmt = $this->pdo->prepare("
-                UPDATE container_deployment_queue 
+                UPDATE whp.container_deployment_queue 
                 SET status = 'completed', processed_at = NOW() 
                 WHERE id = ?
             ");
@@ -143,7 +143,7 @@ class ContainerQueue {
     public function markAsFailed($queue_id, $error_message = null) {
         try {
             $stmt = $this->pdo->prepare("
-                UPDATE container_deployment_queue 
+                UPDATE whp.container_deployment_queue 
                 SET status = 'failed', error_message = ?, processed_at = NOW(),
                     retry_count = retry_count + 1
                 WHERE id = ?
@@ -161,7 +161,7 @@ class ContainerQueue {
     public function retryDeployment($queue_id) {
         try {
             $stmt = $this->pdo->prepare("
-                UPDATE container_deployment_queue 
+                UPDATE whp.container_deployment_queue 
                 SET status = 'pending', error_message = NULL, processed_at = NULL
                 WHERE id = ? AND retry_count < max_retries
             ");
@@ -181,7 +181,7 @@ class ContainerQueue {
                 SELECT 
                     status,
                     COUNT(*) as count
-                FROM container_deployment_queue 
+                FROM whp.container_deployment_queue 
                 WHERE created_at >= DATE_SUB(NOW(), INTERVAL 24 HOUR)
                 GROUP BY status
             ");
@@ -199,7 +199,7 @@ class ContainerQueue {
     public function cleanupOldDeployments($days = 7) {
         try {
             $stmt = $this->pdo->prepare("
-                DELETE FROM container_deployment_queue 
+                DELETE FROM whp.container_deployment_queue 
                 WHERE status IN ('completed', 'failed') 
                 AND created_at < DATE_SUB(NOW(), INTERVAL ? DAY)
             ");
@@ -216,7 +216,7 @@ class ContainerQueue {
     public function checkSiteContainersRunning($site_id) {
         try {
             // Get site info
-            $stmt = $this->pdo->prepare("SELECT domain_name, user FROM sites WHERE id = ?");
+            $stmt = $this->pdo->prepare("SELECT domain_name, username FROM whp.sites WHERE id = ?");
             $stmt->execute([$site_id]);
             $site = $stmt->fetch(PDO::FETCH_ASSOC);
             
