@@ -381,6 +381,11 @@ class WordPressManager {
             $site = $this->getSite($siteId);
             $container = $site['container_name'];
             $user = $site['user'];
+            $domain = $site['domain'];
+        } else {
+            // If container and user are provided, we still need domain
+            $site = $this->getSite($siteId);
+            $domain = $site['domain'];
         }
         
         // Get or create security settings
@@ -419,7 +424,7 @@ Options -Indexes
 ';
         
         // Add .htaccess rules
-        $this->addHtaccessRules($container, $user, $htaccessRules);
+        $this->addHtaccessRules($container, $user, $domain, $htaccessRules);
         
         return ['success' => true];
     }
@@ -1122,8 +1127,8 @@ Options -Indexes
         return $password;
     }
     
-    private function addHtaccessRules($container, $user, $rules) {
-        $path = "/home/{$user}/public_html";
+    private function addHtaccessRules($container, $user, $domain, $rules) {
+        $path = "/home/{$user}/{$domain}/public_html";
         $htaccessPath = "{$path}/.htaccess";
         
         // Use cat with here-document for multi-line content
@@ -1451,6 +1456,7 @@ Options -Indexes
     private function applySecurity($siteId, $site, $settings) {
         $container = $site['container_name'];
         $user = $site['user'];
+        $domain = $site['domain'];
         
         // Disable file editor
         if ($settings['disable_file_editor']) {
@@ -1527,7 +1533,7 @@ Options -Indexes
         
         // Apply .htaccess rules if any
         if (!empty($htaccessRules)) {
-            $this->addHtaccessRules($container, $user, $htaccessRules);
+            $this->addHtaccessRules($container, $user, $domain, $htaccessRules);
         }
     }
     
