@@ -802,8 +802,8 @@ $backupTargets = $stmt->fetchAll(PDO::FETCH_ASSOC);
 </div>
 
 <script>
-// Define nonce for AJAX requests
-const nonce = '<?php echo $_SESSION['nonce'] ?? ''; ?>';
+// Define CSRF token for AJAX requests
+const nonce = '<?php echo get_csrf_token(); ?>';
 
 // Helper function to escape HTML
 function escapeHtml(text) {
@@ -840,6 +840,9 @@ document.addEventListener('DOMContentLoaded', function() {
             
             fetch('/api/wordpress-ajax.php', {
                 method: 'POST',
+                headers: {
+                    'X-CSRF-Token': '<?php echo get_csrf_token(); ?>'
+                },
                 body: formData
             })
             .then(response => response.json())
@@ -939,6 +942,9 @@ document.addEventListener('DOMContentLoaded', function() {
             
             fetch('/api/wordpress-ajax.php', {
                 method: 'POST',
+                headers: {
+                    'X-CSRF-Token': '<?php echo get_csrf_token(); ?>'
+                },
                 body: formData
             })
             .then(response => {
@@ -989,6 +995,9 @@ document.addEventListener('DOMContentLoaded', function() {
             
             fetch('/api/wordpress-ajax.php', {
                 method: 'POST',
+                headers: {
+                    'X-CSRF-Token': '<?php echo get_csrf_token(); ?>'
+                },
                 body: formData
             })
             .then(response => {
@@ -1053,6 +1062,9 @@ document.addEventListener('DOMContentLoaded', function() {
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
+            headers: {
+                'X-CSRF-Token': nonce
+            },
             body: formData
         })
         .then(response => {
@@ -1096,6 +1108,9 @@ document.addEventListener('DOMContentLoaded', function() {
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
+            headers: {
+                'X-CSRF-Token': nonce
+            },
             body: formData
         })
         .then(response => response.json())
@@ -1142,6 +1157,9 @@ document.addEventListener('DOMContentLoaded', function() {
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
+            headers: {
+                'X-CSRF-Token': nonce
+            },
             body: formData
         })
         .then(response => response.json())
@@ -1164,6 +1182,9 @@ document.addEventListener('DOMContentLoaded', function() {
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
+            headers: {
+                'X-CSRF-Token': nonce
+            },
             body: formData
         })
         .then(response => response.json())
@@ -1204,6 +1225,9 @@ document.addEventListener('DOMContentLoaded', function() {
             
             fetch('/api/wordpress-ajax.php', {
                 method: 'POST',
+                headers: {
+                    'X-CSRF-Token': nonce
+                },
                 body: formData
             })
             .then(response => response.json())
@@ -1235,6 +1259,9 @@ document.addEventListener('DOMContentLoaded', function() {
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
+            headers: {
+                'X-CSRF-Token': nonce
+            },
             body: formData
         })
         .then(response => response.json())
@@ -1270,6 +1297,9 @@ document.addEventListener('DOMContentLoaded', function() {
             
             fetch('/api/wordpress-ajax.php', {
                 method: 'POST',
+                headers: {
+                    'X-CSRF-Token': nonce
+                },
                 body: formData
             })
             .then(response => response.json())
@@ -1300,6 +1330,9 @@ document.addEventListener('DOMContentLoaded', function() {
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
+            headers: {
+                'X-CSRF-Token': nonce
+            },
             body: formData
         })
         .then(response => response.json())
@@ -1329,6 +1362,9 @@ document.addEventListener('DOMContentLoaded', function() {
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
+            headers: {
+                'X-CSRF-Token': nonce
+            },
             body: formData
         })
         .then(response => response.json())
@@ -1378,7 +1414,7 @@ document.addEventListener('DOMContentLoaded', function() {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
-                'X-Nonce': nonce
+                'X-CSRF-Token': nonce
             },
             body: 'action=get_recommended_plugins'
         })
@@ -1466,7 +1502,7 @@ document.addEventListener('DOMContentLoaded', function() {
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
             headers: {
-                'X-Nonce': nonce
+                'X-CSRF-Token': nonce
             },
             body: formData
         })
@@ -1496,7 +1532,7 @@ document.addEventListener('DOMContentLoaded', function() {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
-                'X-Nonce': nonce
+                'X-CSRF-Token': nonce
             },
             body: `action=get_recommended_plugin&plugin_id=${pluginId}`
         })
@@ -1523,7 +1559,7 @@ document.addEventListener('DOMContentLoaded', function() {
             method: 'POST',
             headers: {
                 'Content-Type': 'application/x-www-form-urlencoded',
-                'X-Nonce': nonce
+                'X-CSRF-Token': nonce
             },
             body: `action=delete_recommended_plugin&plugin_id=${pluginId}`
         })
@@ -1603,7 +1639,7 @@ function createLoginLink(siteId) {
     fetch('/api/wordpress-ajax.php', {
         method: 'POST',
         headers: {
-            'X-Nonce': nonce
+            'X-CSRF-Token': nonce
         },
         body: formData
     })
@@ -1634,6 +1670,9 @@ function showUpdateModal(siteId) {
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
+            headers: {
+                'X-CSRF-Token': nonce
+            },
             body: formData
         })
         .then(response => response.json())
@@ -1661,6 +1700,9 @@ function pollUpdateStatus(updateId, siteId) {
         
         fetch('/api/wordpress-ajax.php', {
             method: 'POST',
+            headers: {
+                'X-CSRF-Token': nonce
+            },
             body: formData
         })
         .then(response => response.json())
@@ -1721,6 +1763,9 @@ function showSecurityModal(siteId) {
     
     fetch('/api/wordpress-ajax.php', {
         method: 'POST',
+        headers: {
+            'X-CSRF-Token': nonce
+        },
         body: formData
     })
     .then(response => response.json())
@@ -1808,7 +1853,7 @@ function removeFromManagement(siteId) {
     fetch('/api/wordpress-ajax.php', {
         method: 'POST',
         headers: {
-            'X-Nonce': nonce
+            'X-CSRF-Token': nonce
         },
         body: formData
     })
